<template>
    <div id="app" style="overflow-y:auto;">
        <div class="pdf-preview">
            <!-- Canvas elements will be dynamically added here -->
        </div>
        <div class="watermarks">
            <input type="file" ref="fileInput" @change="onFileSelected" style="display: none;" accept="application/pdf">
            <button class="upload-btn" @click="uploadPDF">上传PDF</button>
            <div v-for="watermark in watermarks" :key="watermark.name" :class="['watermark-item', {selected: watermark === selectedWatermark}]" @click="selectWatermark(watermark)">
                <img :src="watermark.url" :alt="watermark.name">
                <p>{{ watermark.name }}</p>
            </div>
            <button class="download-btn" @click="downloadPDF" :disabled="!pdfLoaded">下载PDF</button>
        </div>
    </div>
</template>

<script setup>
import { ref, onMounted, onUnmounted } from 'vue';
const { jsPDF } = window.jspdf;

const pdfPages = ref([]);
const watermarks = ref([
    { name: '测试章1', url: '/server/images/【公章】任丘市华北冀东石化销售有限公司.png' },
    { name: '测试章2', url: '/images/任丘冀东公章旧.png' },
    { name: '测试章3', url: '/server/images/【公章3】测试.png' },
    { name: '测试章4', url: '/server/images/【公章4】测试.png' },
    { name: '测试章5', url: '/server/images/【公章5】测试.png' },
    { name: '测试logo', url: '/images/logo.png' },
]);
const selectedWatermark = ref(null);
const pdfDoc = ref(null);
const pdfLoaded = ref(false);

const loadPDF = async (pdfData) => {
    const pdfPreview = document.querySelector('.pdf-preview');
    pdfPreview.innerHTML = ''; // Clear previous content
    pdfPages.value = [];
    const loadingTask = pdfjsLib.getDocument(pdfData);
    pdfDoc.value = await loadingTask.promise;
    const numPages = pdfDoc.value.numPages;
    pdfPages.value = Array.from({ length: numPages }, (_, i) => i + 1);

    for (let i = 1; i <= numPages; i++) {
        const page = await pdfDoc.value.getPage(i);
        const viewport = page.getViewport({ scale: 1.5 }); // Keep original scale
        const canvas = document.createElement('canvas');
        const context = canvas.getContext('2d');
        canvas.height = viewport.height;
        canvas.width = viewport.width;
        context.fillStyle = "#FFFFFF"; // Set background to white
        context.fillRect(0, 0, canvas.width, canvas.height);
        const renderContext = {
            canvasContext: context,
            viewport: viewport
        };
        await page.render(renderContext).promise;

        pdfPreview.appendChild(canvas);
    }
    pdfLoaded.value = true;
};

const onFileSelected = (event) => {
    const file = event.target.files[0];
    if (file) {
        const reader = new FileReader();
        reader.onload = (e) => {
            const pdfData = new Uint8Array(e.target.result);
            loadPDF({ data: pdfData });
        };
        reader.readAsArrayBuffer(file);
    }
};

const selectWatermark = (watermark) => {
    selectedWatermark.value = watermark;
};

const addWatermark = (event) => {
    if (!selectedWatermark.value) return;

    const canvas = event.target;
    if (!(canvas instanceof HTMLCanvasElement)) return;

    const ctx = canvas.getContext('2d');
    const img = new Image();
    img.onload = () => {
        const scale = 0.28; // 缩小到原来的 28%
        const scaledWidth = img.width * scale;
        const scaledHeight = img.height * scale;
        const x = event.offsetX - scaledWidth / 2;
        const y = event.offsetY - scaledHeight / 2;
        ctx.drawImage(img, x, y, scaledWidth, scaledHeight);
    };
    img.src = selectedWatermark.value.url;
};
const downloadPDF = async () => {
    const pdf = new jsPDF();
    const canvases = document.querySelectorAll('.pdf-preview canvas');
    const totalPages = canvases.length;

    for (let i = 0; i < totalPages; i++) {
        const canvas = canvases[i];
        const imgData = canvas.toDataURL('image/jpeg', 1.0);
        const width = canvas.width;
        const height = canvas.height;
        const pageWidth = 210; // A4 size width in mm
        const pageHeight = 297; // A4 size height in mm
        const ratio = Math.min(pageWidth / width, pageHeight / height);
        const imgWidth = width * ratio;
        const imgHeight = height * ratio;

        if (i > 0) pdf.addPage();
        pdf.addImage(imgData, 'JPEG', 0, 0, imgWidth, imgHeight);
    }

    pdf.save('watermarked.pdf');
};

const uploadPDF = () => {
    document.querySelector('input[type="file"]').click();
};

onMounted(() => {
    document.querySelector('.pdf-preview').addEventListener('click', addWatermark);
});

onUnmounted(() => {
    document.querySelector('.pdf-preview').removeEventListener('click', addWatermark);
});
</script>

<style>
.pdf-preview {
    flex: 1;
    overflow-y: auto;
    border-right: 1px solid #ccc;
    padding: 20px;
    display: flex;
    flex-direction: column;
    align-items: center;
}
.watermarks {
    position: fixed;
    left: 18vh;top: 0;
    width: 200px;
    padding: 20px;
    background-color: #f0f0f0;
}
.watermark-item {
    margin-bottom: 10px;
    cursor: pointer;
}
.watermark-item img {
    max-width: 100%;
    height: auto;
}
.watermark-item.selected {
    border: 2px solid #4CAF50;
}
.download-btn, .upload-btn {
    margin-top: 20px;
    padding: 10px;
    background-color: #4CAF50;
    color: white;
    border: none;
    cursor: pointer;
    width: 100%;
}
.upload-btn {
    background-color: #008CBA;
}
</style>